[![Build Status](https://api.travis-ci.org/uw-it-aca/uw-restclients-pws.svg?branch=master)](https://travis-ci.org/uw-it-aca/uw-restclients-pws)
[![Coverage Status](https://coveralls.io/repos/uw-it-aca/uw-restclients-pws/badge.png?branch=master)](https://coveralls.io/r/uw-it-aca/uw-restclients-pws?branch=master)

# uw-restclients-pws
REST client for the UW Person Web Service
